r"""
Welcome to QuantImPy, a Python Library for scientific image processing.

This code performs morphological operations on Numpy arrays and can compute the
Minkowski functionals and functions. 

This code is inspired by and partly based on the `QuantIm library`_ C/C++ library
for scientific image processing. The source code is available on `Github`_.

This library can be installed using pip:

.. code-block:: python

    pip install quantimpy

If you use this package in your research, please cite it as:

Arnout M.P. Boelens, and Hamdi A. Tchelepi, *QuantImPy: Minkowski functionals
and functions with Python*, SoftwareX, Volume 16, 2021, 100823, ISSN 2352-7110,
doi: `10.1016/j.softx.2021.100823`_,

.. _QuantIm library: https://www.ufz.de/index.php?en=39198
.. _Github: https://github.com/boeleman/quantimpy
.. _10.1016/j.softx.2021.100823: https://doi.org/10.1016/j.softx.2021.100823

"""
